package com.ztmap.project.zhny.lotusnhtj.mapper;

import java.util.List;
import com.ztmap.project.zhny.lotusnhtj.domain.TLotusNhtj;

/**
 * 能耗统计Mapper接口
 * 
 * @author ztmap
 * @date 2023-11-16
 */
public interface TLotusNhtjMapper 
{
    /**
     * 查询能耗统计
     * 
     * @param id 能耗统计ID
     * @return 能耗统计
     */
    public TLotusNhtj selectTLotusNhtjById(Long id);

    /**
     * 查询能耗统计列表
     * 
     * @param tLotusNhtj 能耗统计
     * @return 能耗统计集合
     */
    public List<TLotusNhtj> selectTLotusNhtjList(TLotusNhtj tLotusNhtj);

    /**
     * 新增能耗统计
     * 
     * @param tLotusNhtj 能耗统计
     * @return 结果
     */
    public int insertTLotusNhtj(TLotusNhtj tLotusNhtj);

    /**
     * 修改能耗统计
     * 
     * @param tLotusNhtj 能耗统计
     * @return 结果
     */
    public int updateTLotusNhtj(TLotusNhtj tLotusNhtj);

    /**
     * 删除能耗统计
     * 
     * @param id 能耗统计ID
     * @return 结果
     */
    public int deleteTLotusNhtjById(Long id);

    /**
     * 批量删除能耗统计
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTLotusNhtjByIds(String[] ids);
}
